@@ -6,7 +6,6 @@ import subprocess
 import sys
 
 import fiona
-import numpy as np
 import rasterio
 from rasterio.features import shapes
 
@@ -16,31 +15,31 @@ logger = logging.getLogger('rasterio_polygonize')
 
 
 def main(raster_file, vector_file, driver, mask_value):
-    
-    with rasterio.drivers():
-        
+
+    with rasterio.Env():
+
         with rasterio.open(raster_file) as src:
             image = src.read(1)
-        
+
         if mask_value is not None:
             mask = image == mask_value
         else:
             mask = None
-        
+
         results = (
             {'properties': {'raster_val': v}, 'geometry': s}
-            for i, (s, v) 
+            for i, (s, v)
             in enumerate(
                 shapes(image, mask=mask, transform=src.affine)))
 
         with fiona.open(
-                vector_file, 'w', 
+                vector_file, 'w',
                 driver=driver,
                 crs=src.crs,
                 schema={'properties': [('raster_val', 'int')],
                         'geometry': 'Polygon'}) as dst:
             dst.writerecords(results)
-    
+
     return dst.name
 
 if __name__ == '__main__':
@@ -48,11 +47,11 @@ if __name__ == '__main__':
     parser = argparse.ArgumentParser(
         description="Writes shapes of raster features to a vector file")
     parser.add_argument(
-        'input', 
-        metavar='INPUT', 
+        'input',
+        metavar='INPUT',
         help="Input file name")
     parser.add_argument(
-        'output', 
+        'output',
         metavar='OUTPUT',
         help="Output file name")
     parser.add_argument(
@@ -68,7 +67,6 @@ if __name__ == '__main__':
     args = parser.parse_args()
 
     name = main(args.input, args.output, args.output_driver, args.mask_value)
-    
+
     print subprocess.check_output(
             ['ogrinfo', '-so', args.output, name])
-
