@@ -2,35 +2,31 @@
 
 from __future__ import absolute_import
 
-import json
 import logging
-import time
 import warnings
 
 import numpy as np
 
 import rasterio
 from rasterio._features import _shapes, _sieve, _rasterize, _bounds
+from rasterio.env import ensure_env
 from rasterio.transform import IDENTITY, guard_transform
 from rasterio.dtypes import validate_dtype, can_cast_dtype, get_minimum_dtype
 
 
-log = logging.getLogger('rasterio')
-
-
-class NullHandler(logging.Handler):
-    def emit(self, record):
-        pass
-log.addHandler(NullHandler())
+log = logging.getLogger(__name__)
 
 
+@ensure_env
 def geometry_mask(
         geometries,
         out_shape,
         transform,
         all_touched=False,
         invert=False):
-    """Create a mask from shapes.  By default, mask is intended for use as a
+    """Create a mask from shapes.
+
+    By default, mask is intended for use as a
     numpy mask, where pixels that overlap shapes are False.
 
     Parameters
@@ -55,7 +51,6 @@ def geometry_mask(
     out : numpy ndarray of type 'bool'
         Result
     """
-
     fill, mask_value = (0, 1) if invert else (1, 0)
 
     return rasterize(
@@ -67,10 +62,9 @@ def geometry_mask(
         default_value=mask_value).astype('bool')
 
 
+@ensure_env
 def shapes(image, mask=None, connectivity=4, transform=IDENTITY):
-    """
-    Return a generator of (polygon, value) for each each set of adjacent pixels
-    of the same value.
+    """Yield (polygon, value for each set of adjacent pixels of the same value.
 
     Parameters
     ----------
@@ -87,10 +81,10 @@ def shapes(image, mask=None, connectivity=4, transform=IDENTITY):
         If not provided, feature coordinates will be generated based on pixel
         coordinates
 
-    Returns
+    Yields
     -------
-    Generator of (polygon, value)
-        Yields a pair of (polygon, value) for each feature found in the image.
+    tuple
+        A pair of (polygon, value) for each feature found in the image.
         Polygons are GeoJSON-like dicts and the values are the associated value
         from the image, in the data type of the image.
         Note: due to floating point precision issues, values returned from a
@@ -105,19 +99,16 @@ def shapes(image, mask=None, connectivity=4, transform=IDENTITY):
     memory.
 
     """
-
     transform = guard_transform(transform)
-
-    with rasterio.drivers():
-        for s, v in _shapes(image, mask, connectivity, transform.to_gdal()):
-            yield s, v
+    for s, v in _shapes(image, mask, connectivity, transform.to_gdal()):
+        yield s, v
 
 
+@ensure_env
 def sieve(image, size, out=None, output=None, mask=None, connectivity=4):
-    """
-    Replaces small polygons in `image` with the value of their largest
-    neighbor.  Polygons are found for each set of neighboring pixels of the
-    same value.
+    """Replace small polygons in `image` with value of their largest neighbor.
+
+    Polygons are found for each set of neighboring pixels of the same value.
 
     Parameters
     ----------
@@ -154,7 +145,6 @@ def sieve(image, size, out=None, output=None, mask=None, connectivity=4):
     large amounts of memory.
 
     """
-
     # Start moving users over to 'out'.
     if output is not None:
         warnings.warn(
@@ -162,17 +152,15 @@ def sieve(image, size, out=None, output=None, mask=None, connectivity=4):
             "and will be removed before Rasterio 1.0.",
             FutureWarning,
             stacklevel=2)  # pragma: no cover
-    
-    out = out if out is not None else output
 
+    out = out if out is not None else output
     if out is None:
         out = np.zeros(image.shape, image.dtype)
-
-    with rasterio.drivers():
-        _sieve(image, size, out, mask, connectivity)
-        return out
+    _sieve(image, size, out, mask, connectivity)
+    return out
 
 
+@ensure_env
 def rasterize(
         shapes,
         out_shape=None,
@@ -183,8 +171,7 @@ def rasterize(
         all_touched=False,
         default_value=1,
         dtype=None):
-    """
-    Returns an image array with input geometries burned in.
+    """Return an image array with input geometries burned in.
 
     Parameters
     ----------
@@ -226,7 +213,6 @@ def rasterize(
     rasterio.float64.
 
     """
-
     valid_dtypes = (
         'int16', 'int32', 'uint8', 'uint16', 'uint32', 'float32', 'float64'
     )
@@ -239,7 +225,6 @@ def rasterize(
     def format_cast_error(param, dtype):
         return '{0} cannot be cast to specified dtype: {1}'.format(param, dtype)
 
-
     if fill != 0:
         fill_array = np.array([fill])
         if not validate_dtype(fill_array, valid_dtypes):
@@ -259,7 +244,6 @@ def rasterize(
     if dtype is not None and np.dtype(dtype).name not in valid_dtypes:
         raise ValueError(format_invalid_dtype('dtype'))
 
-
     valid_shapes = []
     shape_values = []
     for index, item in enumerate(shapes):
@@ -270,7 +254,7 @@ def rasterize(
             value = default_value
         geom = getattr(geom, '__geo_interface__', None) or geom
 
-        #not isinstance(geom, dict) or
+        # not isinstance(geom, dict) or
         if 'type' in geom or 'coordinates' in geom:
             valid_shapes.append((geom, value))
             shape_values.append(value)
@@ -299,7 +283,7 @@ def rasterize(
             "The 'output' keyword arg has been superseded by 'out' "
             "and will be removed before Rasterio 1.0.",
             FutureWarning,
-            stacklevel=2) # pragma: no cover
+            stacklevel=2)  # pragma: no cover
 
     out = out if out is not None else output
     if out is not None:
@@ -317,16 +301,14 @@ def rasterize(
         raise ValueError('Either an output shape or image must be provided')
 
     transform = guard_transform(transform)
-
-    with rasterio.drivers():
-        _rasterize(valid_shapes, out, transform.to_gdal(), all_touched)
-
+    _rasterize(valid_shapes, out, transform.to_gdal(), all_touched)
     return out
 
 
 def bounds(geometry):
-    """Returns a (minx, miny, maxx, maxy) bounding box.  From Fiona 1.4.8.
-    Modified to return bbox from geometry if available.
+    """Return a (minx, miny, maxx, maxy) bounding box.
+
+    From Fiona 1.4.8. Modified to return bbox from geometry if available.
 
     Parameters
     ----------
@@ -337,7 +319,6 @@ def bounds(geometry):
     tuple
         Bounding box: (minx, miny, maxx, maxy)
     """
-
     if 'bbox' in geometry:
         return tuple(geometry['bbox'])
 
