@@ -1,14 +1,17 @@
+"""Fill holes in raster dataset by interpolation from the edges."""
+
 import rasterio
 from rasterio._fill import _fillnodata
+from rasterio.env import ensure_env
 
 
+@ensure_env
 def fillnodata(
         image,
         mask=None,
         max_search_distance=100.0,
         smoothing_iterations=0):
-    """
-    Fill holes in a raster dataset by interpolation from the edges.
+    """Fill holes in a raster dataset by interpolation from the edges.
 
     This algorithm will interpolate values for all designated nodata
     pixels (marked by zeros in `mask`). For each pixel a four direction
@@ -48,6 +51,5 @@ def fillnodata(
     """
     max_search_distance = float(max_search_distance)
     smoothing_iterations = int(smoothing_iterations)
-    with rasterio.drivers():
-        return _fillnodata(
-            image, mask, max_search_distance, smoothing_iterations)
+    return _fillnodata(
+        image, mask, max_search_distance, smoothing_iterations)
