@@ -9,18 +9,18 @@ class Profile:
     Subclasses will declare a format driver and driver-specific
     creation options.
     """
+
     driver = None
     defaults = {}
 
     def __call__(self, **kwargs):
-        """Returns a mapping of keyword args for writing a new datasets.
+        """Return a mapping of keyword args for writing a new datasets.
 
         Example:
 
             profile = SomeProfile()
             with rasterio.open('foo.tif', 'w', **profile()) as dst:
                 # Write data ...
-
         """
         if kwargs.get('driver', self.driver) != self.driver:
             raise ValueError(
@@ -33,6 +33,7 @@ class Profile:
 
 class DefaultGTiffProfile(Profile):
     """A tiled, band-interleaved, LZW-compressed, 8-bit GTiff profile."""
+
     driver = 'GTiff'
     defaults = {
         'interleave': 'band',
