@@ -5,8 +5,6 @@ import logging
 import click
 
 import rasterio
-import rasterio.crs
-from rasterio.env import Env
 
 
 @click.command(short_help="Print information about the rio environment.")
@@ -19,7 +17,7 @@ def env(ctx, key):
     """
     verbosity = (ctx.obj and ctx.obj.get('verbosity')) or 1
     stdout = click.get_text_stream('stdout')
-    with Env(CPL_DEBUG=(verbosity > 2)) as env:
+    with rasterio.Env(CPL_DEBUG=(verbosity > 2)) as env:
         if key == 'formats':
             for k, v in sorted(env.drivers().items()):
                 stdout.write("%s: %s\n" % (k, v))
