@@ -5,9 +5,7 @@ import json
 import click
 
 from . import options
-import rasterio.crs
-from rasterio.env import Env
-
+import rasterio
 
 @click.command(short_help="Print information about a data file.")
 @options.file_in_arg
@@ -63,18 +61,20 @@ def info(ctx, input, aspect, indent, namespace, meta_member, verbose, bidx,
     verbosity = ctx.obj.get('verbosity')
     mode = 'r' if (verbose or meta_member == 'stats') else 'r-'
     try:
-        with Env(CPL_DEBUG=(verbosity > 2)):
+        with rasterio.Env(CPL_DEBUG=(verbosity > 2)):
             with rasterio.open(input, mode) as src:
                 info = src.profile
                 info['transform'] = info['affine'][:6]
                 del info['affine']
                 info['shape'] = info['height'], info['width']
                 info['bounds'] = src.bounds
-                proj4 = rasterio.crs.to_string(src.crs)
+                proj4 = src.crs.to_string()
                 if proj4.startswith('+init=epsg'):
                     proj4 = proj4.split('=')[1].upper()
                 info['crs'] = proj4
                 info['res'] = src.res
+                info['colorinterp'] = [src.colorinterp(i).name
+                                       for i in src.indexes]
                 if proj4 != '':
                     info['lnglat'] = src.lnglat()
                 if verbose:
