@@ -1,7 +1,24 @@
+"""Windows and related functions."""
+
+import functools
+import collections
+
+
+def iter_args(function):
+    """Decorator to allow function to take either *args or
+    a single iterable which gets expanded to *args.
+    """
+    @functools.wraps(function)
+    def wrapper(*args, **kwargs):
+        if len(args) == 1 and isinstance(args[0], collections.Iterable):
+            return function(*args[0])
+        else:
+            return function(*args)
+    return wrapper
+
 
 def get_data_window(arr, nodata=None):
-    """
-    Returns a window for the non-nodata pixels within the input array.
+    """Return a window for the non-nodata pixels within the input array.
 
     Parameters
     ----------
@@ -17,14 +34,13 @@ def get_data_window(arr, nodata=None):
     ((row_start, row_stop), (col_start, col_stop))
 
     """
-
     from rasterio._io import get_data_window
     return get_data_window(arr, nodata)
 
 
-def union(windows):
-    """
-    Union windows and return the outermost extent they cover.
+@iter_args
+def union(*windows):
+    """Union windows and return the outermost extent they cover.
 
     Parameters
     ----------
@@ -35,14 +51,13 @@ def union(windows):
     -------
     ((row_start, row_stop), (col_start, col_stop))
     """
-
     from rasterio._io import window_union
     return window_union(windows)
 
 
-def intersection(windows):
-    """
-    Intersect windows and return the innermost extent they cover.
+@iter_args
+def intersection(*windows):
+    """Intersect windows and return the innermost extent they cover.
 
     Will raise ValueError if windows do not intersect.
 
@@ -55,14 +70,13 @@ def intersection(windows):
     -------
     ((row_start, row_stop), (col_start, col_stop))
     """
-
     from rasterio._io import window_intersection
     return window_intersection(windows)
 
 
-def intersect(windows):
-    """
-    Test if windows intersect.
+@iter_args
+def intersect(*windows):
+    """Test if windows intersect.
 
     Parameters
     ----------
@@ -74,6 +88,5 @@ def intersect(windows):
     boolean:
         True if all windows intersect.
     """
-
     from rasterio._io import windows_intersect
     return windows_intersect(windows)
