@@ -7,8 +7,9 @@ import sys
 from click.testing import CliRunner
 import py
 import pytest
-import numpy
+import numpy as np
 
+from rasterio.crs import CRS
 
 DEFAULT_SHAPE = (10, 10)
 
@@ -107,10 +108,10 @@ def basic_image():
     Returns
     -------
 
-    numpy ndarray
+    np ndarray
     """
 
-    image = numpy.zeros(DEFAULT_SHAPE, dtype=numpy.uint8)
+    image = np.zeros(DEFAULT_SHAPE, dtype=np.uint8)
     image[2:5, 2:5] = 1
 
     return image
@@ -126,10 +127,10 @@ def basic_image_2x2():
     Returns
     -------
 
-    numpy ndarray
+    np ndarray
     """
 
-    image = numpy.zeros(DEFAULT_SHAPE, dtype=numpy.uint8)
+    image = np.zeros(DEFAULT_SHAPE, dtype=np.uint8)
     image[2:4, 2:4] = 1
 
     return image
@@ -144,7 +145,7 @@ def pixelated_image(basic_image):
     Returns
     -------
 
-    numpy ndarray
+    np ndarray
     """
 
     image = basic_image.copy()
@@ -162,11 +163,11 @@ def diagonal_image():
     Returns
     -------
 
-    numpy ndarray
+    np ndarray
     """
 
-    image = numpy.zeros(DEFAULT_SHAPE, dtype=numpy.uint8)
-    numpy.fill_diagonal(image, 1)
+    image = np.zeros(DEFAULT_SHAPE, dtype=np.uint8)
+    np.fill_diagonal(image, 1)
     return image
 
 
@@ -190,7 +191,7 @@ def basic_image_file(tmpdir, basic_image):
 
     outfilename = str(tmpdir.join('basic_image.tif'))
     kwargs = {
-        "crs": {'init': 'epsg:4326'},
+        "crs": CRS({'init': 'epsg:4326'}),
         "transform": Affine.identity(),
         "count": 1,
         "dtype": rasterio.uint8,
@@ -225,7 +226,7 @@ def pixelated_image_file(tmpdir, pixelated_image):
 
     outfilename = str(tmpdir.join('pixelated_image.tif'))
     kwargs = {
-        "crs": {'init': 'epsg:4326'},
+        "crs": CRS({'init': 'epsg:4326'}),
         "transform": Affine.identity(),
         "count": 1,
         "dtype": rasterio.uint8,
@@ -249,3 +250,8 @@ def gdalenv(request):
             rasterio.env.delenv()
             rasterio.env._env = None
     request.addfinalizer(fin)
+
+
+@pytest.fixture(scope='module')
+def path_rgb_byte_tif():
+    return os.path.join('tests', 'data', 'RGB.byte.tif')
