@@ -1,7 +1,7 @@
 import pytest
 
 import rasterio
-from rasterio.enums import ColorInterp, PhotometricInterp
+from rasterio.enums import ColorInterp
 
 
 def test_cmyk_interp(tmpdir):
@@ -19,6 +19,7 @@ def test_cmyk_interp(tmpdir):
         assert dst.colorinterp(4) == ColorInterp.black
 
 
+@pytest.mark.skip(reason="crashing on OS X with Homebrew's GDAL")
 def test_ycbcr_interp(tmpdir):
     """A YCbCr TIFF has red, green, blue bands."""
     with rasterio.open('tests/data/RGB.byte.tif') as src:
