@@ -1,22 +1,20 @@
 import logging
-import sys
 
 import rasterio
 from rasterio._drivers import driver_count
-from rasterio.env import Env
 
 
 def test_drivers():
-    with Env() as m:
+    with rasterio.Env() as m:
         assert driver_count() > 0
-        assert type(m) == Env
+        assert type(m) == rasterio.Env
     assert driver_count() > 0
 
 
 def test_drivers_bwd_compat():
-    with rasterio.drivers() as m:
+    with rasterio.Env() as m:
         assert driver_count() > 0
-        assert type(m) == Env
+        assert type(m) == rasterio.Env
     assert driver_count() > 0
 
 
@@ -28,7 +26,7 @@ def test_cpl_debug_true(tmpdir):
     fh = logging.FileHandler(logfile)
     log.addHandler(fh)
 
-    with Env(CPL_DEBUG=True):
+    with rasterio.Env(CPL_DEBUG=True):
         with rasterio.open("tests/data/RGB.byte.tif"):
             pass
 
@@ -44,7 +42,7 @@ def test_cpl_debug_false(tmpdir):
     fh = logging.FileHandler(logfile)
     log.addHandler(fh)
 
-    with Env(CPL_DEBUG=False):
+    with rasterio.Env(CPL_DEBUG=False):
         with rasterio.open("tests/data/RGB.byte.tif"):
             pass
 
