@@ -4,7 +4,7 @@ import subprocess
 import re
 
 import affine
-import numpy
+import numpy as np
 import pytest
 
 import rasterio
@@ -25,7 +25,7 @@ def test_update_tags(data):
 def test_update_band(data):
     tiffname = str(data.join('RGB.byte.tif'))
     with rasterio.open(tiffname, 'r+') as f:
-        f.write(numpy.zeros(f.shape, dtype=f.dtypes[0]), indexes=1)
+        f.write(np.zeros(f.shape, dtype=f.dtypes[0]), indexes=1)
     with rasterio.open(tiffname) as f:
         assert not f.read(1).any()
 
