@@ -32,13 +32,13 @@ def test_parse_path_file_scheme():
 def test_parse_path_file():
     """Correctly parse an ordinary filesystem path"""
     assert parse_path('/foo.tif') == (
-        '/foo.tif', None, None)
+        '/foo.tif', None, '')
 
 
-def test_parse_unknown_scheme():
-    """Raise exception for unknown WFS scheme"""
-    with pytest.raises(ValueError):
-        parse_path('gopher://foo.tif')
+def test_parse_netcdf():
+    """Annoying URI-like GDAL dataset names fall through properly"""
+    assert parse_path('NETCDF:filepath:varname') == (
+        'NETCDF:filepath:varname', None, None)
 
 
 def test_vsi_path_scheme():
@@ -47,12 +47,6 @@ def test_vsi_path_scheme():
         'foo.tif', 'tests/data/files.zip', 'zip') == '/vsizip/tests/data/files.zip/foo.tif'
 
 
-def test_vsi_path_file():
-    """Correctly make a ordinary file path from a parsed file:// URL"""
-    assert vsi_path(
-        'foo.tif', None, 'file') == 'foo.tif'
-
-
 def test_vsi_path_file():
     """Correctly make and ordinary file path from a file path"""
     assert vsi_path(
@@ -95,7 +89,7 @@ def test_read_vfs_none():
 def test_update_vfs(tmpdir, mode):
     """VFS datasets can not be created or updated"""
     with pytest.raises(TypeError):
-        _ = rasterio.open(
+        rasterio.open(
             'zip://{0}'.format(tmpdir), mode,
             **default_gtiff_profile(
                 count=1, width=1, height=1))
